@@ -48,6 +48,12 @@
 #include "../processing/filters/filterresample.h"
 
 
+int massSpectrumMetaTypeId =
+  qRegisterMetaType<pappso::MassSpectrum>("pappso::MassSpectrum");
+int massSpectrumPtrMetaTypeId =
+  qRegisterMetaType<pappso::MassSpectrum *>("pappso::MassSpectrum *");
+
+
 namespace pappso
 {
 
