@@ -52,6 +52,13 @@
 #include "mzintegrationparams.h"
 
 
+int mzIntegrationParamsMetaTypeId =
+  qRegisterMetaType<pappso::MzIntegrationParams>("pappso::MzIntegrationParams");
+int mzIntegrationParamsPtrMetaTypeId =
+  qRegisterMetaType<pappso::MzIntegrationParams *>(
+    "pappso::MzIntegrationParams *");
+
+
 namespace pappso
 {
 
@@ -383,23 +390,23 @@ std::vector<double>
 MzIntegrationParams::createArbitraryBins()
 {
 
-  //qDebug();
+  // qDebug();
 
   // Now starts the tricky stuff. Depending on how the binning has been
   // configured, we need to take diverse actions.
 
-  //qDebug() << "Bin specification:" << mp_precision->toString();
+  // qDebug() << "Bin specification:" << mp_precision->toString();
 
   pappso::pappso_double min_mz = m_smallestMz;
   pappso::pappso_double max_mz = m_greatestMz;
 
-  //qDebug() << QString::asprintf("min_mz: %.6f\n", min_mz)
-           //<< QString::asprintf("max_mz: %.6f\n", max_mz);
+  // qDebug() << QString::asprintf("min_mz: %.6f\n", min_mz)
+  //<< QString::asprintf("max_mz: %.6f\n", max_mz);
 
   pappso::pappso_double binSize = mp_precision->delta(min_mz);
 
-  //qDebug() << QString::asprintf(
-    //"binSize is the precision delta for min_mz: %.6f\n", binSize);
+  // qDebug() << QString::asprintf(
+  //"binSize is the precision delta for min_mz: %.6f\n", binSize);
 
   // Only compute the decimal places if they were not configured already.
   if(m_decimalPlaces == -1)
@@ -462,10 +469,11 @@ MzIntegrationParams::createArbitraryBins()
       // Calculate dynamically the precision delta according to the current mz
       // value.
 
-      //double precision_delta = mp_precision->delta(previous_mz_bin);
+      // double precision_delta = mp_precision->delta(previous_mz_bin);
       // qDebug() << "precision_delta: " << precision_delta;
 
-      double current_mz = previous_mz_bin + mp_precision->delta(previous_mz_bin);
+      double current_mz =
+        previous_mz_bin + mp_precision->delta(previous_mz_bin);
 
       // qDebug() << QString::asprintf(
       //"previous_mzBin: %.6f and current_mz: %.6f\n",
@@ -730,6 +738,5 @@ MzIntegrationParams::toString(int offset, const QString &spacer) const
   return text;
 }
 
-
 } // namespace pappso
 
