@@ -39,6 +39,7 @@
 #include "../../precision.h"
 #include "../../massspectrum/massspectrum.h"
 
+
 namespace pappso
 {
 
@@ -83,61 +84,61 @@ extern std::map<BinningType, QString> binningTypeMap;
 */
 class PMSPP_LIB_DECL MzIntegrationParams
 {
-
   public:
-  MzIntegrationParams();
-  MzIntegrationParams(pappso::pappso_double minMz,
-                      pappso::pappso_double maxMz,
-                      BinningType binningType,
-                      int decimalPlaces,
-                      pappso::PrecisionPtr precisionPtr,
-                      bool applyMzShift,
-                      pappso::pappso_double mzShift,
-                      bool removeZeroValDataPoints);
+  Q_INVOKABLE MzIntegrationParams();
+  Q_INVOKABLE MzIntegrationParams(pappso::pappso_double minMz,
+                                  pappso::pappso_double maxMz,
+                                  BinningType binningType,
+                                  int decimalPlaces,
+                                  pappso::PrecisionPtr precisionPtr,
+                                  bool applyMzShift,
+                                  pappso::pappso_double mzShift,
+                                  bool removeZeroValDataPoints);
 
-  MzIntegrationParams(const MzIntegrationParams &other);
+  Q_INVOKABLE MzIntegrationParams(const MzIntegrationParams &other);
 
   virtual ~MzIntegrationParams();
 
   MzIntegrationParams &operator=(const MzIntegrationParams &other);
 
-  void setSmallestMz(pappso::pappso_double value);
-  void updateSmallestMz(pappso::pappso_double value);
+  Q_INVOKABLE void setSmallestMz(pappso::pappso_double value);
+  Q_INVOKABLE void updateSmallestMz(pappso::pappso_double value);
   pappso::pappso_double getSmallestMz() const;
 
-  void setGreatestMz(pappso::pappso_double value);
-  void updateGreatestMz(pappso::pappso_double value);
-  pappso::pappso_double getGreatestMz() const;
+  Q_INVOKABLE void setGreatestMz(pappso::pappso_double value);
+  Q_INVOKABLE void updateGreatestMz(pappso::pappso_double value);
+  Q_INVOKABLE pappso::pappso_double getGreatestMz() const;
 
-  void setBinningType(BinningType binningType);
-  BinningType getBinningType() const;
+  Q_INVOKABLE void setBinningType(BinningType binningType);
+  Q_INVOKABLE BinningType getBinningType() const;
 
-  void setDecimalPlaces(int decimal_places);
-  int getDecimalPlaces() const;
+  Q_INVOKABLE void setDecimalPlaces(int decimal_places);
+  Q_INVOKABLE int getDecimalPlaces() const;
 
-  void setPrecision(pappso::PrecisionPtr precisionPtr);
-  pappso::PrecisionPtr getPrecision() const;
+  Q_INVOKABLE void setPrecision(pappso::PrecisionPtr precisionPtr);
+  Q_INVOKABLE pappso::PrecisionPtr getPrecision() const;
 
-  void setApplyMzShift(bool applyMzShift);
-  bool isApplyMzShift() const;
+  Q_INVOKABLE void setApplyMzShift(bool applyMzShift);
+  Q_INVOKABLE bool isApplyMzShift() const;
 
-  void setMzShift(double value);
-  double getMzShift() const;
+  Q_INVOKABLE void setMzShift(double value);
+  Q_INVOKABLE double getMzShift() const;
 
-  void setRemoveZeroValDataPoints(bool removeOrNot = true);
-  bool isRemoveZeroValDataPoints() const;
+  Q_INVOKABLE void setRemoveZeroValDataPoints(bool removeOrNot = true);
+  Q_INVOKABLE bool isRemoveZeroValDataPoints() const;
 
-  void reset();
+  Q_INVOKABLE void reset();
 
-  bool isValid() const;
+  Q_INVOKABLE bool isValid() const;
 
-  bool hasValidMzRange() const;
+  Q_INVOKABLE bool hasValidMzRange() const;
 
-  std::vector<pappso::pappso_double> createBins();
-  std::vector<pappso::pappso_double>
+  Q_INVOKABLE std::vector<pappso::pappso_double> createBins();
+  Q_INVOKABLE std::vector<pappso::pappso_double>
   createBins(pappso::MassSpectrumCstSPtr mass_spectrum_csp);
 
-  QString toString(int offset = 0, const QString &spacer = QString()) const;
+  Q_INVOKABLE QString toString(int offset            = 0,
+                               const QString &spacer = QString()) const;
 
   private:
   // That smallest value needs to be set to max, because it will be necessary
@@ -167,3 +168,10 @@ class PMSPP_LIB_DECL MzIntegrationParams
 
 
 } // namespace pappso
+
+Q_DECLARE_METATYPE(pappso::MzIntegrationParams);
+Q_DECLARE_METATYPE(pappso::MzIntegrationParams *);
+
+extern int mzIntegrationParamsMetaTypeId;
+extern int mzIntegrationParamsPtrMetaTypeId;
+
