@@ -8,6 +8,7 @@
 #include <iomanip>
 
 #include <QDebug>
+#include <QObject>
 
 #include "trace.h"
 #include "maptrace.h"
@@ -28,6 +29,42 @@ int tracePtrMetaTypeId = qRegisterMetaType<pappso::Trace *>("pappso::Trace *");
 namespace pappso
 {
 
+QDataStream &
+operator<<(QDataStream &out, const Trace &trace)
+{
+  for(auto &dataPoint : trace)
+    {
+      out << dataPoint.x;
+      out << dataPoint.y;
+      out << "\n";
+    }
+  out << "\n";
+
+  return out;
+}
+
+
+QDataStream &
+operator>>(QDataStream &in, Trace &trace)
+{
+  if(in.atEnd())
+    {
+      throw PappsoException(
+        QString("error in QDataStream unserialize operator>> of trace:\n"
+                "read datastream failed status=%1")
+          .arg(in.status()));
+    }
+
+  for(auto &dataPoint : trace)
+    {
+      in >> dataPoint.x;
+      in >> dataPoint.y;
+    }
+
+  return in;
+}
+
+
 std::vector<DataPoint>::iterator
 findFirstEqualOrGreaterX(std::vector<DataPoint>::iterator begin,
                          std::vector<DataPoint>::iterator end,
@@ -90,10 +127,12 @@ findDifferentYvalue(std::vector<DataPoint>::iterator begin,
                     const double &y_value)
 {
   return std::find_if(begin, end, [y_value](const DataPoint &to_compare) {
+
     if(to_compare.y != y_value)
       {
         return true;
       }
+
     return false;
   });
 }
@@ -104,10 +143,12 @@ findDifferentYvalue(std::vector<DataPoint>::const_iterator begin,
                     const double &y_value)
 {
   return std::find_if(begin, end, [y_value](const DataPoint &to_compare) {
+
     if(to_compare.y != y_value)
       {
         return true;
       }
+
     return false;
   });
 }
@@ -464,7 +505,8 @@ Trace::Trace(const Trace &other) : std::vector<DataPoint>(other)
 }
 
 
-Trace::Trace(const Trace &&other) : std::vector<DataPoint>(std::move(other))
+Trace::Trace(const Trace &&other)
+  : std::vector<DataPoint>(std::move(other))
 {
   // This constructor used by the MassSpectrum && constructor.
 }
@@ -537,6 +579,15 @@ Trace::initialize(const Trace &other)
 }
 
 
+size_t
+Trace::append(const DataPoint &data_point)
+{
+  push_back(data_point);
+
+  return size();
+}
+
+
 Trace &
 Trace::operator=(const Trace &other)
 {
