@@ -178,6 +178,10 @@ class PMSPP_LIB_DECL Trace : public std::vector<DataPoint>
   TraceSPtr makeTraceSPtr() const;
   TraceCstSPtr makeTraceCstSPtr() const;
 
+  /** @brief appends a datapoint and return new size
+   */
+  size_t append(const DataPoint &data_point);
+
   std::vector<pappso_double> xValues() const;
   std::vector<pappso_double> yValues() const;
 
@@ -210,14 +214,17 @@ class PMSPP_LIB_DECL Trace : public std::vector<DataPoint>
   virtual Trace &filter(const FilterInterface &filter) final;
   QString toString() const;
 
+  /** @brief find datapoint with exactly x value
+   */
+  std::vector<DataPoint>::const_iterator
+  dataPointCstIteratorWithX(pappso_double value) const;
+
   protected:
   //! Return a reference to the DataPoint instance that has its y member equal
   //! to \p value.
   // const DataPoint &dataPointWithX(pappso_double value) const;
   std::size_t dataPointIndexWithX(pappso_double value) const;
   std::vector<DataPoint>::iterator dataPointIteratorWithX(pappso_double value);
-  std::vector<DataPoint>::const_iterator
-  dataPointCstIteratorWithX(pappso_double value) const;
 };
 
 
