@@ -53,7 +53,8 @@ Utils::getLexicalOrderedString(unsigned int num)
 {
   int size = log10(num);
   size += 97;
-  QString base(size);
+  QLatin1Char latin1_char(size);
+  QString base(latin1_char);
   base.append(QString().setNum(num));
   return (base);
 }
@@ -427,4 +428,44 @@ Utils::booleanToString(bool value)
   return "FALSE";
 }
 
+QString
+Utils::mzFormatAsString(MzFormat mz_format)
+{
+  
+  if(mz_format == MzFormat::mzML)
+    return "mzML";
+  else if(mz_format == MzFormat::mzXML)
+    return "mzXML";
+  else if(mz_format == MzFormat::MGF)
+    return "MGF";
+  else if(mz_format == MzFormat::SQLite3)
+    return "SQLite3";
+  else if(mz_format == MzFormat::xy)
+    return "xy";
+  else if(mz_format == MzFormat::mz5)
+    return "mz5";
+  else if(mz_format == MzFormat::msn)
+    return "msn";
+  else if(mz_format == MzFormat::abSciexWiff)
+    return "abSciexWiff";
+  else if(mz_format == MzFormat::abSciexT2D)
+    return "abSciexT2D";
+  else if(mz_format == MzFormat::agilentMassHunter)
+    return "agilentMassHunter";
+  else if(mz_format == MzFormat::thermoRaw)
+    return "thermoRaw";
+  else if(mz_format == MzFormat::watersRaw)
+    return "watersRaw";
+  else if(mz_format == MzFormat::brukerFid)
+    return "brukerFid";
+  else if(mz_format == MzFormat::brukerYep)
+    return "brukerYep";
+  else if(mz_format == MzFormat::brukerBaf)
+    return "brukerBaf";
+  else if(mz_format == MzFormat::brukerTims)
+    return "brukerTims";
+  else
+    return "unknown";
+}
+
 } // namespace pappso
