@@ -37,7 +37,6 @@
 #include "../../types.h"
 
 #include "massspectraceplotwidget.h"
-#include "../../pappsoexception.h"
 #include "massspectraceplotcontext.h"
 
 
@@ -56,12 +55,7 @@ namespace pappso
 MassSpecTracePlotWidget::MassSpecTracePlotWidget(QWidget *parent)
   : BaseTracePlotWidget(parent)
 {
-  // Set the base context to be of kind DataKind::mz;
-
-  BasePlotWidget::m_context.m_dataKind = DataKind::mz;
-
-  // And then initialize ours with the base class' one.
-  m_context.m_baseContext = BasePlotWidget::m_context;
+  m_context.m_dataKind = DataKind::mz;
 
   // qDebug() << "Data kind:" <<
   // static_cast<int>(m_context.m_baseContext.m_dataKind);
@@ -74,10 +68,7 @@ MassSpecTracePlotWidget::MassSpecTracePlotWidget(QWidget *parent,
 {
   // Set the base context to be of kind DataKind::mz;
 
-  BasePlotWidget::m_context.m_dataKind = DataKind::mz;
-
-  // And then initialize ours with the base class' one.
-  m_context.m_baseContext = BasePlotWidget::m_context;
+  m_context.m_dataKind = DataKind::mz;
 
   // qDebug() << "Data kind:" <<
   // static_cast<int>(m_context.m_baseContext.m_dataKind);
@@ -103,10 +94,6 @@ MassSpecTracePlotWidget::keyPressEvent(QKeyEvent *event)
   // qDebug() << "Going to emit keyPressEventSignal(m_context);";
 
   emit keyPressEventSignal(m_context);
-  emit testKeyPressEventSignal(m_context);
-  emit newKeyPressEventSignal(
-    pappso::DataPoint(m_context.m_baseContext.m_currentDragPoint.x(),
-                      m_context.m_baseContext.m_currentDragPoint.y()));
 }
 
 
@@ -166,9 +153,9 @@ MassSpecTracePlotWidget::mouseMoveHandlerDraggingCursor()
   // to get it from the base class and refresh our local context with it.
   refreshBaseContext();
 
-  if(m_context.m_baseContext.m_mouseButtonsAtMousePress & Qt::LeftButton)
+  if(m_context.m_mouseButtonsAtMousePress & Qt::LeftButton)
     {
-      if(!m_context.m_baseContext.m_isMeasuringDistance)
+      if(!m_context.m_isMeasuringDistance)
         return;
 
       // qDebug() << "lastMovingMouseButtons:"
@@ -207,7 +194,18 @@ MassSpecTracePlotWidget::mouseReleaseHandler(QMouseEvent *event)
 const MassSpecTracePlotContext &
 MassSpecTracePlotWidget::refreshBaseContext() const
 {
-  m_context.m_baseContext = BasePlotWidget::m_context;
+  // BasePlotWidget has a member m_context of type BasePlotContext.
+  // Here we also have a m_context *distinct* member that is of type
+  // MassSpecTracePlotContext.
+
+  // While MassSpecTracePlotContext is derived from BasePlotContext, the two
+  // m_context members are distinct and there are lots of housekeeping data that
+  // are managed by the parent BasePlotWidget class in its m_context member
+  // *independently* of what we have in the ::BasePlotContext part of our
+  // m_context member that is of type MassSpecTracePlotContext. We thus need to
+  // resynchronize the data from BasePlotWidget::m_context to our m_context.
+
+  m_context = BasePlotWidget::m_context;
 
   return m_context;
 }
@@ -260,8 +258,7 @@ MassSpecTracePlotWidget::deconvolute()
   // on the fractional part of the deconvoluted charge value. This value is set
   // in the parent window's double spin box.
 
-  if(fabs(m_context.m_baseContext.m_xDelta) >= 0 &&
-     fabs(m_context.m_baseContext.m_xDelta) <= 1.1)
+  if(fabs(m_context.m_xDelta) >= 0 && fabs(m_context.m_xDelta) <= 1.1)
     {
       // qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
       //<< "m_xDelta:" << m_context.m_baseContext.m_xDelta
@@ -313,8 +310,8 @@ MassSpecTracePlotWidget::deconvoluteChargedState(int span)
   // currentDragPoint, that is the value in
   // m_context.m_baseContext.m_xRegionRange.upper.
 
-  double startMz = m_context.m_baseContext.m_xRegionRangeStart;
-  double curMz   = m_context.m_baseContext.m_xRegionRangeEnd;
+  double startMz = m_context.m_xRegionRangeStart;
+  double curMz   = m_context.m_xRegionRangeEnd;
 
   // qDebug() << "startMz:" << startMz << "curMz:" << curMz;
 
@@ -459,8 +456,7 @@ bool
 MassSpecTracePlotWidget::deconvoluteIsotopicCluster()
 {
 
-  if(m_context.m_baseContext.m_xRegionRangeStart ==
-     m_context.m_baseContext.m_xRegionRangeEnd)
+  if(m_context.m_xRegionRangeStart == m_context.m_xRegionRangeEnd)
     {
       // qDebug() << __FILE__ << __LINE__
       //<< "Same xRegionRange.upper and xRegionRange.lower:"
@@ -469,7 +465,7 @@ MassSpecTracePlotWidget::deconvoluteIsotopicCluster()
       return false;
     }
 
-  double chargeTemp = 1 / fabs(m_context.m_baseContext.m_xDelta);
+  double chargeTemp = 1 / fabs(m_context.m_xDelta);
 
   // Make a judicious roundup.
   double chargeIntPart;
@@ -519,8 +515,8 @@ MassSpecTracePlotWidget::deconvoluteIsotopicCluster()
   // We need to sort the xRegionRange before being certain that lower is indeed
   // the left value of the drag span.
 
-  m_context.m_lastMz = std::min<double>(m_context.m_baseContext.m_xRegionRangeStart,
-                                      m_context.m_baseContext.m_xRegionRangeEnd);
+  m_context.m_lastMz = std::min<double>(m_context.m_xRegionRangeStart,
+                                        m_context.m_xRegionRangeEnd);
 
   m_context.m_lastMr =
     (m_context.m_lastMz * m_context.m_lastZ) - (m_context.m_lastZ * MPROTON);
@@ -544,7 +540,7 @@ MassSpecTracePlotWidget::computeResolvingPower()
   // during mouve movement handling. Note that the range values *are
   // sorted*.
 
-  if(!m_context.m_baseContext.m_xDelta || m_context.m_baseContext.m_xDelta > 1)
+  if(!m_context.m_xDelta || m_context.m_xDelta > 1)
     {
       m_context.m_lastResolvingPower = std::numeric_limits<double>::min();
 
@@ -554,10 +550,10 @@ MassSpecTracePlotWidget::computeResolvingPower()
   // Resolving power is m/z / Delta(m/z), for singly-charged species.
 
   m_context.m_lastResolvingPower =
-    (std::min<double>(m_context.m_baseContext.m_xRegionRangeStart,
-                      m_context.m_baseContext.m_xRegionRangeEnd) +
-     (m_context.m_baseContext.m_xDelta / 2)) /
-    m_context.m_baseContext.m_xDelta;
+    (std::min<double>(m_context.m_xRegionRangeStart,
+                      m_context.m_xRegionRangeEnd) +
+     (m_context.m_xDelta / 2)) /
+    m_context.m_xDelta;
 
   // The m_context was refreshed with the base class context in the calling
   // chain.
